from django.contrib import admin
from django.contrib.auth.admin import GroupAdmin, UserAdmin
from django.contrib.auth.models import Group, User
from django.shortcuts import redirect
from django.urls import reverse

from accounts.settings import accounts_settings


class LabsAdminSite(admin.AdminSite):

    def login(self, request, extra_context=None):
        if not request.user.is_authenticated:
            return redirect(reverse('accounts:login') + '?next=' + request.GET.get('next'))
        return super().login(request, extra_context)


if accounts_settings.CUSTOM_ADMIN:
    admin.site = LabsAdminSite()
    admin.site.register(Group, GroupAdmin)
    admin.site.register(User, UserAdmin)



from django.contrib.auth import get_user_model
from django.contrib.auth.backends import RemoteUserBackend

from accounts.settings import accounts_settings


class LabsUserBackend(RemoteUserBackend):
    def authenticate(self, request, remote_user):
        if not remote_user:
            return
        User = get_user_model()
        user, created = User.objects.get_or_create(username=remote_user['username'])
        if created:
            user.first_name = remote_user['first_name']
            user.last_name = remote_user['last_name']
            user.email = remote_user['email']
            user.set_unusable_password()
            user.save()
            try:
                user = self.configure_user(request, user)
            except TypeError:
                user = self.configure_user(user)

        if accounts_settings.ADMIN_PERMISSION in remote_user['product_permission']:
            user.is_staff = True
            user.is_superuser = True
            user.save()
        return user if self.user_can_authenticate(user) else None
